Struct ColorGlyph

pub struct ColorGlyph<'a> { /* private fields */ }
A representation of a color glyph that can be painted through a sequence of ColorPainter callbacks.

Implementations



impl<'a> ColorGlyph<'a>

pub fn format(&self) -> ColorGlyphFormat

Returns the version of the color table from which this outline was selected.

pub fn bounding_box( &self, location: impl Into<LocationRef<'a>>, size: Size, ) -> Option<BoundingBox<f32>>

Returns the bounding box.

For COLRv1 glyphs, this is the clip box of the specified COLRv1 glyph, or None if clip boxes are not present or if there is none for the particular glyph.

Always returns None for COLRv0 glyphs because precomputed clip boxes are never available.

The size argument can optionally be used to scale the bounding box to a particular font size and location allows specifying a variation instance.

pub fn paint( &self, location: impl Into<LocationRef<'a>>, painter: &mut impl ColorPainter, ) -> Result<(), PaintError>

Evaluates the paint graph at the specified location in variation space and emits the results to the given painter.

For a COLRv1 glyph, traverses the COLRv1 paint graph and invokes drawing callbacks on a specified ColorPainter trait object. The traversal operates in font units and will call ColorPainter methods with font unit values. This means, if you want to draw a COLRv1 glyph at a particular font size, the canvas needs to have a transformation matrix applied so that it scales down the drawing operations to font_size / upem.

Arguments
  • glyph_id the GlyphId to be drawn.
  • location coordinates for specifying a variation instance. This can be empty.
  • painter a client-provided ColorPainter implementation receiving drawing callbacks.